/***************************************************************************
 *            net_dir_scan.c
 *
 *  Fri Oct 24 11:27:21 2003
 *  Copyright  2003  Phil Kett
 *  pkett@genesis-midi.com
 ****************************************************************************/

#include "../include/remsync.h"
#include <sys/socket.h>

void
net_dir_scan (int fd, char *basedir, int depth)
{
	char curdir[BIG_BUF], message[BIG_BUF], mode[BIG_BUF];
	char owner[BIG_BUF], group[BIG_BUF], linktarg[BIG_BUF];
	struct dirent *d;
	DIR *dir;
	int checksum, isdir;
	bzero (message, BIG_BUF);

	dir = opendir (basedir);
	getperms (basedir, mode);
	getowner (basedir, owner, group);
	if (conf.debug) syslog (LOG_INFO, "Basedir is %s\n", basedir);
	sprintf (message, "CSUM:%s:%s:%s:%s:DIRECTORY\r\n", basedir, mode,
		 owner, group);
	send (fd, message, strlen (message), 0);

	while ((d = readdir (dir)))
	{
		bzero (owner, BIG_BUF);
		bzero (group, BIG_BUF);
		bzero (mode, BIG_BUF);

		if (strcmp (d->d_name, ".") != 0
		    && strcmp (d->d_name, "..") != 0)
		{
			sprintf (curdir, "%s%s", basedir, d->d_name);
			if (is_a_link (curdir) == 1)
			{
				/* it's a symlink - handle accordingly */
				getperms (curdir, mode);
				getowner (curdir, owner, group);
				realpath(curdir, linktarg);
				sprintf (message,
						 "CSUM:%s:%s:%s:%s:LINK\r\n",
						 curdir, linktarg, owner, group);
					send (fd, message, strlen (message),
					      0);
				
			}
			else
			{
				isdir = is_a_dir (curdir);
				if (isdir == 1)
				{
					depth++;
					if (conf.debug) printf ("Directory depth %d\n", depth);
					checkslash (curdir);
					net_dir_scan (fd, curdir, depth);
				}
				else if (isdir == 0)
				{
					
					/* Size??? */
					getperms (curdir, mode);
					getowner (curdir, owner, group);
					checksum = cksum (curdir);
					sprintf (message,
						 "CSUM:%s:%s:%s:%s:%d\r\n",
						 curdir, mode, owner, group,
						 checksum);
					send (fd, message, strlen (message),
					      0);

				}
			}
		}
	}
	closedir (dir);
}
